Entrypoints reference
=====================

Reference to entrypoints provided by pubtools pyxis. The entrypoints are expected to be invoked with a CLI.


.. toctree::
   :maxdepth: 1

   get_indices
   get_repo_metadata
   upload_signatures
   get_signatures
   delete_signatures